@@ -1,3 +1,5 @@
+#!/usr/bin/env python
+
 import io
 import sys
 import timeit
@@ -5,8 +7,9 @@ import argparse
 import traceback
 import logging
 import os
+
 try:
-    from fastspell import FastSpell
+    from . import FastSpell
 except ImportError:
     import FastSpell    
 
@@ -14,7 +17,7 @@ except ImportError:
 __author__ = "Marta Bañón"
 __version__ = "Version 0.1 # 01/07/2021 # Initial release # Marta Bañón"
 __version__ = "Version 0.1.1 # 01/07/2021 # More flexible management of paths and imports # Marta Bañón"
-
+__version__ = "Version 0.2 # 25/10/2021 # Removed tokenization # Marta Bañón"
 
 
 def logging_setup(args = None):
